@@ -14,7 +14,7 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 """command line wrapper for lgp.changelog"""
 
 import sys
@@ -50,9 +50,6 @@ COMMAND COMMANDS_ARGS
   add <message>
     add a message to the current entry
     
-  update
-    update the change log by fectching log entries from cvs
-
   close
     close the current entry (version is read from the package
     __pkginfo__.py file)
@@ -99,9 +96,6 @@ def run(args):
         chlg.extract(arg)
     elif args[0] == 'lastrev':
         print chlg.get_latest_revision()
-    elif args[0] == 'update':
-        chlg.update(create)
-        chlg.save()
     elif args[0] == 'add':
         assert args[1]
         chlg.add(' '.join(args[1:]), create)
